@@ -43,7 +43,8 @@
 
 
 from pymongo.connection import Connection
-from mongoalchemy.query import Query
+from mongoalchemy.query import Query, QueryResult, RemoveQuery
+from mongoalchemy.document import FieldNotRetrieved
 
 class Session(object):
 
@@ -58,6 +59,7 @@ class Session(object):
         '''
         self.db = database
         self.queue = []
+        self.safe = False
     
     @classmethod
     def connect(self, database, *args, **kwds):
@@ -93,7 +95,75 @@ class Session(object):
         # This really should be adding a query operation to the 
         # queue which is then forced to execute when the results are being
         # read
-        return Query(type, self.db)
+        return Query(type, self)
+    
+    def execute_query(self, query):
+        ''' Get the results of ``query``.  This method will flush the queue '''
+        collection = self.db[query.type.get_collection_name()]
+        for index in query.type.get_indexes():
+            index.ensure(collection)
+        
+        kwargs = dict()
+        if query.get_fields():
+            kwargs['fields'] = [str(f) for f in query.get_fields()]
+        
+        cursor = collection.find(query.query, **kwargs)
+        
+        if query.sort:
+            cursor.sort(query.sort)
+        if query.hints:
+            cursor.hint(query.hints)
+        if query.get_limit() != None:
+            cursor.limit(query.get_limit())
+        if query.get_skip() != None:
+            cursor.skip(query.get_skip())
+        return QueryResult(cursor, query.type, fields=query.get_fields())
+    
+    def remove_query(self, type):
+        ''' Begin a remove query on the database's collection for `type`.
+  
+           .. seealso:: :class:`~mongoalchemy.update_expression.RemoveQuery` class'''
+        return RemoveQuery(type, self)
+    
+    def remove(self, obj, safe=None):
+        '''
+            Remove a particular object from the database.  If the object has 
+            no mongo ID set, the method just returns.  If this is a partial 
+            document without the mongo ID field retrieved a ``FieldNotRetrieved``
+            will be raised
+            
+            **Parameters**:
+                * obj: the object to save
+                * safe: whether to wait for the operation to complete.  Defaults \
+                    to the session's ``safe`` value.
+        '''
+        self.flush()
+        if safe == None:
+            safe = self.safe
+        if not obj.has_id():
+            return None
+        return self.db[obj.get_collection_name()].remove(obj.mongo_id, safe=safe)
+    
+    def execute_remove(self, remove):
+        ''' Execute a remove expression.  Should generally only be called implicitly.
+        '''
+        self.flush()
+        safe = self.safe
+        if remove.safe != None:
+            safe = remove.safe
+        return self.db[remove.type.get_collection_name()].remove(remove.query, safe=safe)
+    
+    def execute_update(self, update):
+        ''' Execute an update expression.  Should generally only be called implicitly.
+        '''
+
+        self.flush()
+        assert len(update.update_data) > 0
+        collection = self.db[update.query.type.get_collection_name()]
+        for index in update.query.type.get_indexes():
+            index.ensure(collection)
+        collection.update(update.query.query, update.update_data, upsert=update.get_upsert(), multi=update.get_multi())
+
     
     def get_indexes(self, cls):
         ''' Get the index information for the collection associated with 
@@ -117,6 +187,8 @@ class Session(object):
         ''' Perform all database operations currently in the queue'''
         for index, item in enumerate(self.queue):
             item.commit(self.db)
+        self.clear()
+            
     
     def __enter__(self):
         return self
